\name{depthSuit}
\alias{depthSuit}
\title{
A function for assessing soil depth suitability requirements for certain crops
}
\description{
This function determines the suitability classes for soil depth requirements of selected agricultural crops
}
\usage{
depthSuit(value, crop)
}
\arguments{
  \item{value}{
Input soil depth in cm.
}
\item{crop}{
The crop of interest for which soil depth suitability class is sought.
}
}
\details{
The input value can be map or just a numerical entry of soil depth in cm
}
\value{
The output is soil depth suitability class for the crop. The output is integer value for suitability class: 1- highly suitable; 2 - moderately suitable; 3 - marginally suitable; 4 - currently not suitable; 5 - not suitable
}
\references{
Sys, C., Van Ranst, E., Debaveye, J. and Beerneaert, F.1993. Land evaluation: Part III: Crop requirements.
Development Cooperation, Belgium.

Naidu, L.G.K., Ramamurthy, V., Challa O., Hegde, R. and Krishnan, P. 2006. Manual, Soil-site Suitability Criteria for Major Crops, National Bureau of Soil Survey and Land Use Planning, ICAR, Nagpur, India

FAO Crop Suitability Requirements: http://ecocrop.fao.org/ecocrop/srv/en/home
}
\author{
Christian Thine Omuto
}
\seealso{
tempSuit, ESPSuit, classCode
}
\examples{
library(sp)
library(raster)
LUT=data.frame(map=c(1,2,3,4,5,6),new=c(100,20,30,40,60,80))
newmap=as(suitabinput["depthcodes"],"RasterLayer")
newmap$depth=reclassifyMap(newmap$depthcodes,LUT)
newmap1=as(newmap,"SpatialGridDataFrame")
newmap1$melon=depthSuit(newmap1$depth,"melon")
summary(newmap1$melon)
spplot(newmap1["melon"])
}
